#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmobar
version:              0.50
visibility:           public
id:                   xmobar-0.50-FUcPs9VBzIs4b2AL2W5rVd
key:                  xmobar-0.50-FUcPs9VBzIs4b2AL2W5rVd
license:              BSD-3-Clause
maintainer:           Jose A. Ortega Ruiz <jao@gnu.org>
author:               Andrea Rossato and Jose A. Ortega Ruiz
homepage:             https://codeberg.org/xmobar/xmobar
synopsis:             A Minimalistic Text Based Status Bar
description:
    Xmobar is a minimalistic text based status bar.

    Inspired by the Ion3 status bar, it supports similar
    features, like dynamic color management, output templates,
    and extensibility through plugins.

category:             System
abi:                  fb4772ef128a19b16e959d473fa207c6
exposed:              True
exposed-modules:
    Xmobar Xmobar.Plugins.Accordion Xmobar.Plugins.Monitors.Common
    Xmobar.Plugins.Monitors.Common.Run
    Xmobar.Plugins.Monitors.Common.Types Xmobar.Plugins.Monitors.Cpu

hidden-modules:
    Paths_xmobar Xmobar.Config.Types Xmobar.Config.Parse
    Xmobar.Config.Template Xmobar.Run.Types Xmobar.Run.Timer
    Xmobar.Run.Template Xmobar.Run.Exec Xmobar.Run.Runnable
    Xmobar.Run.Actions Xmobar.Run.Loop Xmobar.Draw.Boxes
    Xmobar.Draw.Cairo Xmobar.Draw.Types Xmobar.App.Config
    Xmobar.App.Main Xmobar.App.Opts Xmobar.App.Compile
    Xmobar.System.Utils Xmobar.System.StatFS Xmobar.System.Environment
    Xmobar.System.Localize Xmobar.System.Signal Xmobar.System.Kbd
    Xmobar.Text.Ansi Xmobar.Text.Loop Xmobar.Text.Pango
    Xmobar.Text.Swaybar Xmobar.Text.SwaybarClicks Xmobar.Text.Output
    Xmobar.X11.Bitmap Xmobar.X11.CairoSurface Xmobar.X11.ColorCache
    Xmobar.X11.Draw Xmobar.X11.Events Xmobar.X11.Loop Xmobar.X11.Text
    Xmobar.X11.Types Xmobar.X11.Window Xmobar.Plugins.ArchUpdates
    Xmobar.Plugins.Command Xmobar.Plugins.BufferedPipeReader
    Xmobar.Plugins.CommandReader Xmobar.Plugins.Date
    Xmobar.Plugins.EWMH Xmobar.Plugins.HandleReader
    Xmobar.Plugins.QueueReader Xmobar.Plugins.PacmanUpdates
    Xmobar.Plugins.PipeReader Xmobar.Plugins.MarqueePipeReader
    Xmobar.Plugins.StdinReader Xmobar.Plugins.XMonadLog
    Xmobar.Plugins.Kbd Xmobar.Plugins.Locks Xmobar.Plugins.NotmuchMail
    Xmobar.Plugins.Monitors Xmobar.Plugins.Monitors.Batt
    Xmobar.Plugins.Monitors.Batt.Common
    Xmobar.Plugins.Monitors.Common.Output
    Xmobar.Plugins.Monitors.Common.Parsers
    Xmobar.Plugins.Monitors.Common.Files
    Xmobar.Plugins.Monitors.CoreTemp Xmobar.Plugins.Monitors.K10Temp
    Xmobar.Plugins.Monitors.Cpu.Common Xmobar.Plugins.Monitors.CpuFreq
    Xmobar.Plugins.Monitors.Disk Xmobar.Plugins.Monitors.Disk.Common
    Xmobar.Plugins.Monitors.Load Xmobar.Plugins.Monitors.Load.Common
    Xmobar.Plugins.Monitors.Mem Xmobar.Plugins.Monitors.MultiCoreTemp
    Xmobar.Plugins.Monitors.MultiCpu Xmobar.Plugins.Monitors.Net
    Xmobar.Plugins.Monitors.Net.Common Xmobar.Plugins.Monitors.Swap
    Xmobar.Plugins.Monitors.Thermal Xmobar.Plugins.Monitors.ThermalZone
    Xmobar.Plugins.Monitors.Top Xmobar.Plugins.Monitors.Top.Common
    Xmobar.Plugins.Monitors.Uptime Xmobar.Plugins.Monitors.Bright
    Xmobar.Plugins.Monitors.CatInt Xmobar.X11.XRender
    Xmobar.Plugins.Mail Xmobar.Plugins.MBox
    Xmobar.Plugins.Monitors.Wireless Xmobar.Plugins.Monitors.MPD
    Xmobar.Plugins.Monitors.Volume Xmobar.Plugins.Monitors.Alsa
    Xmobar.Plugins.DateZone Xmobar.Plugins.Monitors.Mpris
    Xmobar.System.DBus Xmobar.X11.XPMFile
    Xmobar.Plugins.Monitors.Weather Xmobar.Plugins.Monitors.Batt.Linux
    Xmobar.Plugins.Monitors.Cpu.Linux
    Xmobar.Plugins.Monitors.Disk.Linux
    Xmobar.Plugins.Monitors.Load.Linux
    Xmobar.Plugins.Monitors.Mem.Linux Xmobar.Plugins.Monitors.Net.Linux
    Xmobar.Plugins.Monitors.Swap.Linux
    Xmobar.Plugins.Monitors.Top.Linux
    Xmobar.Plugins.Monitors.Uptime.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.6.6/xmobar-0.50
hs-libraries:         HSxmobar-0.50-FUcPs9VBzIs4b2AL2W5rVd
extra-libraries:      Xrandr Xrender Xpm
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    X11-xft-0.3.4-JGao0F7ospv80yY0xwg9ng
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    alsa-core-0.5.0.1-DS67XwizAMDDx6BMv2E7yf
    alsa-mixer-0.3.0.1-D5NqpzQN3mDH3TSCPqK4Sy
    async-2.2.6-13RsU0DgnQr2Fu0srq1209 base-4.18.2.1
    bytestring-0.11.5.3 cairo-0.13.12.0-647oT1UddqBFW0nZilJc7C
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    colour-2.3.7-LvQs8ewmnio1Lssq54nOFL containers-0.6.7
    dbus-1.3.3-B1OXO7F4ZIuFirmUlfL59o directory-1.3.8.5
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    extra-1.7.16-5TJRL61mQdJ37nJ79jr8U filepath-1.4.300.1
    hinotify-0.4.2-yTsE0B4pbp1Rpm0XPOnbC
    http-client-tls-0.3.6.4-5gkLBXAH8K17sWQOnZNh1
    http-conduit-2.3.9.1-B5KHgbNCduWKP1fVPwgDda
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    libmpd-0.10.0.1-Juh1adMh0qHHItTaKZJ2W4 mtl-2.3.1
    netlink-1.1.1.0-KpOHoTN78YV9rxKbrmfxyA
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    pango-0.13.11.0-7m1BWtZgRDICjlB9xQu498 parsec-3.1.16.1
    parsec-numbers-0.1.0-CQgBTSiqAipDiSzjYC83B3 process-1.6.19.0
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag stm-2.5.1.0
    time-1.12.2 timezone-olson-0.2.1-6NOwi40H6SOHnOnPRUwiEr
    timezone-series-0.1.13-2xWMpmU9QsD6fXDaZdBg8o transformers-0.6.1.0
    unix-2.8.4.0 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:
    /usr/share/doc/x86_64-linux-ghc-9.6.6/xmobar-0.50/html/xmobar.haddock

haddock-html:         /usr/share/doc/x86_64-linux-ghc-9.6.6/xmobar-0.50/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

